# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['EmailCustomizationArgs', 'EmailCustomization']

@pulumi.input_type
class EmailCustomizationArgs:
    def __init__(__self__, *,
                 brand_id: pulumi.Input[_builtins.str],
                 template_name: pulumi.Input[_builtins.str],
                 body: Optional[pulumi.Input[_builtins.str]] = None,
                 force_is_default: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 language: Optional[pulumi.Input[_builtins.str]] = None,
                 subject: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a EmailCustomization resource.
        :param pulumi.Input[_builtins.str] brand_id: Brand ID
        :param pulumi.Input[_builtins.str] template_name: Template Name - Example values: `AccountLockout`,`ADForgotPassword`,`ADForgotPasswordDenied`,`ADSelfServiceUnlock`,`ADUserActivation`,`AuthenticatorEnrolled`,`AuthenticatorReset`,`ChangeEmailConfirmation`,`EmailChallenge`,`EmailChangeConfirmation`,`EmailFactorVerification`,`ForgotPassword`,`ForgotPasswordDenied`,`IGAReviewerEndNotification`,`IGAReviewerNotification`,`IGAReviewerPendingNotification`,`IGAReviewerReassigned`,`LDAPForgotPassword`,`LDAPForgotPasswordDenied`,`LDAPSelfServiceUnlock`,`LDAPUserActivation`,`MyAccountChangeConfirmation`,`NewSignOnNotification`,`OktaVerifyActivation`,`PasswordChanged`,`PasswordResetByAdmin`,`PendingEmailChange`,`RegistrationActivation`,`RegistrationEmailVerification`,`SelfServiceUnlock`,`SelfServiceUnlockOnUnlockedAccount`,`UserActivation`
        :param pulumi.Input[_builtins.str] body: The body of the customization
        :param pulumi.Input[_builtins.str] force_is_default: Force is_default on the create and delete by deleting all email customizations. Comma separated string with values of 'create' or 'destroy' or both `create,destroy'.
        :param pulumi.Input[_builtins.bool] is_default: Whether the customization is the default
        :param pulumi.Input[_builtins.str] language: The language supported by the customization - Example values from [supported languages](https://developer.okta.com/docs/reference/api/brands/#supported-languages)
        :param pulumi.Input[_builtins.str] subject: The subject of the customization
        """
        pulumi.set(__self__, "brand_id", brand_id)
        pulumi.set(__self__, "template_name", template_name)
        if body is not None:
            pulumi.set(__self__, "body", body)
        if force_is_default is not None:
            warnings.warn("""force_is_default is deprecated and now is a no-op in behavior. Rely upon the depends_on meta argument to force dependency of secondary templates to the default template""", DeprecationWarning)
            pulumi.log.warn("""force_is_default is deprecated: force_is_default is deprecated and now is a no-op in behavior. Rely upon the depends_on meta argument to force dependency of secondary templates to the default template""")
        if force_is_default is not None:
            pulumi.set(__self__, "force_is_default", force_is_default)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if language is not None:
            pulumi.set(__self__, "language", language)
        if subject is not None:
            pulumi.set(__self__, "subject", subject)

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> pulumi.Input[_builtins.str]:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "brand_id", value)

    @_builtins.property
    @pulumi.getter(name="templateName")
    def template_name(self) -> pulumi.Input[_builtins.str]:
        """
        Template Name - Example values: `AccountLockout`,`ADForgotPassword`,`ADForgotPasswordDenied`,`ADSelfServiceUnlock`,`ADUserActivation`,`AuthenticatorEnrolled`,`AuthenticatorReset`,`ChangeEmailConfirmation`,`EmailChallenge`,`EmailChangeConfirmation`,`EmailFactorVerification`,`ForgotPassword`,`ForgotPasswordDenied`,`IGAReviewerEndNotification`,`IGAReviewerNotification`,`IGAReviewerPendingNotification`,`IGAReviewerReassigned`,`LDAPForgotPassword`,`LDAPForgotPasswordDenied`,`LDAPSelfServiceUnlock`,`LDAPUserActivation`,`MyAccountChangeConfirmation`,`NewSignOnNotification`,`OktaVerifyActivation`,`PasswordChanged`,`PasswordResetByAdmin`,`PendingEmailChange`,`RegistrationActivation`,`RegistrationEmailVerification`,`SelfServiceUnlock`,`SelfServiceUnlockOnUnlockedAccount`,`UserActivation`
        """
        return pulumi.get(self, "template_name")

    @template_name.setter
    def template_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "template_name", value)

    @_builtins.property
    @pulumi.getter
    def body(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The body of the customization
        """
        return pulumi.get(self, "body")

    @body.setter
    def body(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "body", value)

    @_builtins.property
    @pulumi.getter(name="forceIsDefault")
    @_utilities.deprecated("""force_is_default is deprecated and now is a no-op in behavior. Rely upon the depends_on meta argument to force dependency of secondary templates to the default template""")
    def force_is_default(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Force is_default on the create and delete by deleting all email customizations. Comma separated string with values of 'create' or 'destroy' or both `create,destroy'.
        """
        return pulumi.get(self, "force_is_default")

    @force_is_default.setter
    def force_is_default(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "force_is_default", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the customization is the default
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter
    def language(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The language supported by the customization - Example values from [supported languages](https://developer.okta.com/docs/reference/api/brands/#supported-languages)
        """
        return pulumi.get(self, "language")

    @language.setter
    def language(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "language", value)

    @_builtins.property
    @pulumi.getter
    def subject(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The subject of the customization
        """
        return pulumi.get(self, "subject")

    @subject.setter
    def subject(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subject", value)


@pulumi.input_type
class _EmailCustomizationState:
    def __init__(__self__, *,
                 body: Optional[pulumi.Input[_builtins.str]] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 force_is_default: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 language: Optional[pulumi.Input[_builtins.str]] = None,
                 links: Optional[pulumi.Input[_builtins.str]] = None,
                 subject: Optional[pulumi.Input[_builtins.str]] = None,
                 template_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EmailCustomization resources.
        :param pulumi.Input[_builtins.str] body: The body of the customization
        :param pulumi.Input[_builtins.str] brand_id: Brand ID
        :param pulumi.Input[_builtins.str] force_is_default: Force is_default on the create and delete by deleting all email customizations. Comma separated string with values of 'create' or 'destroy' or both `create,destroy'.
        :param pulumi.Input[_builtins.bool] is_default: Whether the customization is the default
        :param pulumi.Input[_builtins.str] language: The language supported by the customization - Example values from [supported languages](https://developer.okta.com/docs/reference/api/brands/#supported-languages)
        :param pulumi.Input[_builtins.str] links: Link relations for this object - JSON HAL - Discoverable resources related to the email template
        :param pulumi.Input[_builtins.str] subject: The subject of the customization
        :param pulumi.Input[_builtins.str] template_name: Template Name - Example values: `AccountLockout`,`ADForgotPassword`,`ADForgotPasswordDenied`,`ADSelfServiceUnlock`,`ADUserActivation`,`AuthenticatorEnrolled`,`AuthenticatorReset`,`ChangeEmailConfirmation`,`EmailChallenge`,`EmailChangeConfirmation`,`EmailFactorVerification`,`ForgotPassword`,`ForgotPasswordDenied`,`IGAReviewerEndNotification`,`IGAReviewerNotification`,`IGAReviewerPendingNotification`,`IGAReviewerReassigned`,`LDAPForgotPassword`,`LDAPForgotPasswordDenied`,`LDAPSelfServiceUnlock`,`LDAPUserActivation`,`MyAccountChangeConfirmation`,`NewSignOnNotification`,`OktaVerifyActivation`,`PasswordChanged`,`PasswordResetByAdmin`,`PendingEmailChange`,`RegistrationActivation`,`RegistrationEmailVerification`,`SelfServiceUnlock`,`SelfServiceUnlockOnUnlockedAccount`,`UserActivation`
        """
        if body is not None:
            pulumi.set(__self__, "body", body)
        if brand_id is not None:
            pulumi.set(__self__, "brand_id", brand_id)
        if force_is_default is not None:
            warnings.warn("""force_is_default is deprecated and now is a no-op in behavior. Rely upon the depends_on meta argument to force dependency of secondary templates to the default template""", DeprecationWarning)
            pulumi.log.warn("""force_is_default is deprecated: force_is_default is deprecated and now is a no-op in behavior. Rely upon the depends_on meta argument to force dependency of secondary templates to the default template""")
        if force_is_default is not None:
            pulumi.set(__self__, "force_is_default", force_is_default)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if language is not None:
            pulumi.set(__self__, "language", language)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if subject is not None:
            pulumi.set(__self__, "subject", subject)
        if template_name is not None:
            pulumi.set(__self__, "template_name", template_name)

    @_builtins.property
    @pulumi.getter
    def body(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The body of the customization
        """
        return pulumi.get(self, "body")

    @body.setter
    def body(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "body", value)

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "brand_id", value)

    @_builtins.property
    @pulumi.getter(name="forceIsDefault")
    @_utilities.deprecated("""force_is_default is deprecated and now is a no-op in behavior. Rely upon the depends_on meta argument to force dependency of secondary templates to the default template""")
    def force_is_default(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Force is_default on the create and delete by deleting all email customizations. Comma separated string with values of 'create' or 'destroy' or both `create,destroy'.
        """
        return pulumi.get(self, "force_is_default")

    @force_is_default.setter
    def force_is_default(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "force_is_default", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the customization is the default
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter
    def language(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The language supported by the customization - Example values from [supported languages](https://developer.okta.com/docs/reference/api/brands/#supported-languages)
        """
        return pulumi.get(self, "language")

    @language.setter
    def language(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "language", value)

    @_builtins.property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Link relations for this object - JSON HAL - Discoverable resources related to the email template
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "links", value)

    @_builtins.property
    @pulumi.getter
    def subject(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The subject of the customization
        """
        return pulumi.get(self, "subject")

    @subject.setter
    def subject(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subject", value)

    @_builtins.property
    @pulumi.getter(name="templateName")
    def template_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Template Name - Example values: `AccountLockout`,`ADForgotPassword`,`ADForgotPasswordDenied`,`ADSelfServiceUnlock`,`ADUserActivation`,`AuthenticatorEnrolled`,`AuthenticatorReset`,`ChangeEmailConfirmation`,`EmailChallenge`,`EmailChangeConfirmation`,`EmailFactorVerification`,`ForgotPassword`,`ForgotPasswordDenied`,`IGAReviewerEndNotification`,`IGAReviewerNotification`,`IGAReviewerPendingNotification`,`IGAReviewerReassigned`,`LDAPForgotPassword`,`LDAPForgotPasswordDenied`,`LDAPSelfServiceUnlock`,`LDAPUserActivation`,`MyAccountChangeConfirmation`,`NewSignOnNotification`,`OktaVerifyActivation`,`PasswordChanged`,`PasswordResetByAdmin`,`PendingEmailChange`,`RegistrationActivation`,`RegistrationEmailVerification`,`SelfServiceUnlock`,`SelfServiceUnlockOnUnlockedAccount`,`UserActivation`
        """
        return pulumi.get(self, "template_name")

    @template_name.setter
    def template_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "template_name", value)


@pulumi.type_token("okta:index/emailCustomization:EmailCustomization")
class EmailCustomization(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 body: Optional[pulumi.Input[_builtins.str]] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 force_is_default: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 language: Optional[pulumi.Input[_builtins.str]] = None,
                 subject: Optional[pulumi.Input[_builtins.str]] = None,
                 template_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create an email customization of an email template belonging to a brand in an Okta organization.
        		Use this resource to create an [email
        		customization](https://developer.okta.com/docs/reference/api/brands/#create-email-customization)
        		of an email template belonging to a brand in an Okta organization.
        		> Okta's public API is strict regarding the behavior of the 'is_default'
        		property in [an email
        		customization](https://developer.okta.com/docs/reference/api/brands/#email-customization).
        		Make use of 'depends_on' meta argument to ensure the provider navigates email customization
        		language versions seamlessly. Have all secondary customizations depend on the primary
        		customization that is marked default. See Example Usage.
        		> Caveats for [creating an email
        		customization](https://developer.okta.com/docs/reference/api/brands/#response-body-19).
        		If this is the first customization being created for the email template, and
        		'is_default' is not set for the customization in its resource configuration, the
        		API will respond with the created customization marked as default. The API will
        		400 if the language parameter is not one of the supported languages or the body
        		parameter does not contain a required variable reference. The API will error 409
        		if 'is_default' is true and a default customization exists. The API will 404 for
        		an invalid 'brand_id' or 'template_name'.
        		> Caveats for [updating an email
        		customization](https://developer.okta.com/docs/reference/api/brands/#response-body-22).
        		If the 'is_default' parameter is true, the previous default email customization
        		has its 'is_default' set to false (see previous note about mitigating this with
        		'depends_on' meta argument). The API will 409 if there’s already another email
        		customization for the specified language or the 'is_default' parameter is false
        		and the email customization being updated is the default. The API will 400 if
        		the language parameter is not one of the supported locales or the body parameter
        		does not contain a required variable reference.  The API will 404 for an invalid
        		'brand_id' or 'template_name'.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.get_brands()
        forgot_password = okta.get_email_customizations(brand_id=test.brands[0].id,
            template_name="ForgotPassword")
        forgot_password_en = okta.EmailCustomization("forgot_password_en",
            brand_id=test.brands[0].id,
            template_name="ForgotPassword",
            language="en",
            is_default=True,
            subject="Account password reset",
            body="Hi $$user.firstName,<br/><br/>Click this link to reset your password: $$resetPasswordLink")
        forgot_password_es = okta.EmailCustomization("forgot_password_es",
            brand_id=test.brands[0].id,
            template_name="ForgotPassword",
            language="es",
            subject="Restablecimiento de contraseña de cuenta",
            body="Hola $$user.firstName,<br/><br/>Haga clic en este enlace para restablecer tu contraseña: $$resetPasswordLink",
            opts = pulumi.ResourceOptions(depends_on=[forgot_password_en]))
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/emailCustomization:EmailCustomization example <customization_id>/<brand_id>/<template_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] body: The body of the customization
        :param pulumi.Input[_builtins.str] brand_id: Brand ID
        :param pulumi.Input[_builtins.str] force_is_default: Force is_default on the create and delete by deleting all email customizations. Comma separated string with values of 'create' or 'destroy' or both `create,destroy'.
        :param pulumi.Input[_builtins.bool] is_default: Whether the customization is the default
        :param pulumi.Input[_builtins.str] language: The language supported by the customization - Example values from [supported languages](https://developer.okta.com/docs/reference/api/brands/#supported-languages)
        :param pulumi.Input[_builtins.str] subject: The subject of the customization
        :param pulumi.Input[_builtins.str] template_name: Template Name - Example values: `AccountLockout`,`ADForgotPassword`,`ADForgotPasswordDenied`,`ADSelfServiceUnlock`,`ADUserActivation`,`AuthenticatorEnrolled`,`AuthenticatorReset`,`ChangeEmailConfirmation`,`EmailChallenge`,`EmailChangeConfirmation`,`EmailFactorVerification`,`ForgotPassword`,`ForgotPasswordDenied`,`IGAReviewerEndNotification`,`IGAReviewerNotification`,`IGAReviewerPendingNotification`,`IGAReviewerReassigned`,`LDAPForgotPassword`,`LDAPForgotPasswordDenied`,`LDAPSelfServiceUnlock`,`LDAPUserActivation`,`MyAccountChangeConfirmation`,`NewSignOnNotification`,`OktaVerifyActivation`,`PasswordChanged`,`PasswordResetByAdmin`,`PendingEmailChange`,`RegistrationActivation`,`RegistrationEmailVerification`,`SelfServiceUnlock`,`SelfServiceUnlockOnUnlockedAccount`,`UserActivation`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EmailCustomizationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create an email customization of an email template belonging to a brand in an Okta organization.
        		Use this resource to create an [email
        		customization](https://developer.okta.com/docs/reference/api/brands/#create-email-customization)
        		of an email template belonging to a brand in an Okta organization.
        		> Okta's public API is strict regarding the behavior of the 'is_default'
        		property in [an email
        		customization](https://developer.okta.com/docs/reference/api/brands/#email-customization).
        		Make use of 'depends_on' meta argument to ensure the provider navigates email customization
        		language versions seamlessly. Have all secondary customizations depend on the primary
        		customization that is marked default. See Example Usage.
        		> Caveats for [creating an email
        		customization](https://developer.okta.com/docs/reference/api/brands/#response-body-19).
        		If this is the first customization being created for the email template, and
        		'is_default' is not set for the customization in its resource configuration, the
        		API will respond with the created customization marked as default. The API will
        		400 if the language parameter is not one of the supported languages or the body
        		parameter does not contain a required variable reference. The API will error 409
        		if 'is_default' is true and a default customization exists. The API will 404 for
        		an invalid 'brand_id' or 'template_name'.
        		> Caveats for [updating an email
        		customization](https://developer.okta.com/docs/reference/api/brands/#response-body-22).
        		If the 'is_default' parameter is true, the previous default email customization
        		has its 'is_default' set to false (see previous note about mitigating this with
        		'depends_on' meta argument). The API will 409 if there’s already another email
        		customization for the specified language or the 'is_default' parameter is false
        		and the email customization being updated is the default. The API will 400 if
        		the language parameter is not one of the supported locales or the body parameter
        		does not contain a required variable reference.  The API will 404 for an invalid
        		'brand_id' or 'template_name'.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.get_brands()
        forgot_password = okta.get_email_customizations(brand_id=test.brands[0].id,
            template_name="ForgotPassword")
        forgot_password_en = okta.EmailCustomization("forgot_password_en",
            brand_id=test.brands[0].id,
            template_name="ForgotPassword",
            language="en",
            is_default=True,
            subject="Account password reset",
            body="Hi $$user.firstName,<br/><br/>Click this link to reset your password: $$resetPasswordLink")
        forgot_password_es = okta.EmailCustomization("forgot_password_es",
            brand_id=test.brands[0].id,
            template_name="ForgotPassword",
            language="es",
            subject="Restablecimiento de contraseña de cuenta",
            body="Hola $$user.firstName,<br/><br/>Haga clic en este enlace para restablecer tu contraseña: $$resetPasswordLink",
            opts = pulumi.ResourceOptions(depends_on=[forgot_password_en]))
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/emailCustomization:EmailCustomization example <customization_id>/<brand_id>/<template_name>
        ```

        :param str resource_name: The name of the resource.
        :param EmailCustomizationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EmailCustomizationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 body: Optional[pulumi.Input[_builtins.str]] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 force_is_default: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 language: Optional[pulumi.Input[_builtins.str]] = None,
                 subject: Optional[pulumi.Input[_builtins.str]] = None,
                 template_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EmailCustomizationArgs.__new__(EmailCustomizationArgs)

            __props__.__dict__["body"] = body
            if brand_id is None and not opts.urn:
                raise TypeError("Missing required property 'brand_id'")
            __props__.__dict__["brand_id"] = brand_id
            __props__.__dict__["force_is_default"] = force_is_default
            __props__.__dict__["is_default"] = is_default
            __props__.__dict__["language"] = language
            __props__.__dict__["subject"] = subject
            if template_name is None and not opts.urn:
                raise TypeError("Missing required property 'template_name'")
            __props__.__dict__["template_name"] = template_name
            __props__.__dict__["links"] = None
        super(EmailCustomization, __self__).__init__(
            'okta:index/emailCustomization:EmailCustomization',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            body: Optional[pulumi.Input[_builtins.str]] = None,
            brand_id: Optional[pulumi.Input[_builtins.str]] = None,
            force_is_default: Optional[pulumi.Input[_builtins.str]] = None,
            is_default: Optional[pulumi.Input[_builtins.bool]] = None,
            language: Optional[pulumi.Input[_builtins.str]] = None,
            links: Optional[pulumi.Input[_builtins.str]] = None,
            subject: Optional[pulumi.Input[_builtins.str]] = None,
            template_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'EmailCustomization':
        """
        Get an existing EmailCustomization resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] body: The body of the customization
        :param pulumi.Input[_builtins.str] brand_id: Brand ID
        :param pulumi.Input[_builtins.str] force_is_default: Force is_default on the create and delete by deleting all email customizations. Comma separated string with values of 'create' or 'destroy' or both `create,destroy'.
        :param pulumi.Input[_builtins.bool] is_default: Whether the customization is the default
        :param pulumi.Input[_builtins.str] language: The language supported by the customization - Example values from [supported languages](https://developer.okta.com/docs/reference/api/brands/#supported-languages)
        :param pulumi.Input[_builtins.str] links: Link relations for this object - JSON HAL - Discoverable resources related to the email template
        :param pulumi.Input[_builtins.str] subject: The subject of the customization
        :param pulumi.Input[_builtins.str] template_name: Template Name - Example values: `AccountLockout`,`ADForgotPassword`,`ADForgotPasswordDenied`,`ADSelfServiceUnlock`,`ADUserActivation`,`AuthenticatorEnrolled`,`AuthenticatorReset`,`ChangeEmailConfirmation`,`EmailChallenge`,`EmailChangeConfirmation`,`EmailFactorVerification`,`ForgotPassword`,`ForgotPasswordDenied`,`IGAReviewerEndNotification`,`IGAReviewerNotification`,`IGAReviewerPendingNotification`,`IGAReviewerReassigned`,`LDAPForgotPassword`,`LDAPForgotPasswordDenied`,`LDAPSelfServiceUnlock`,`LDAPUserActivation`,`MyAccountChangeConfirmation`,`NewSignOnNotification`,`OktaVerifyActivation`,`PasswordChanged`,`PasswordResetByAdmin`,`PendingEmailChange`,`RegistrationActivation`,`RegistrationEmailVerification`,`SelfServiceUnlock`,`SelfServiceUnlockOnUnlockedAccount`,`UserActivation`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EmailCustomizationState.__new__(_EmailCustomizationState)

        __props__.__dict__["body"] = body
        __props__.__dict__["brand_id"] = brand_id
        __props__.__dict__["force_is_default"] = force_is_default
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["language"] = language
        __props__.__dict__["links"] = links
        __props__.__dict__["subject"] = subject
        __props__.__dict__["template_name"] = template_name
        return EmailCustomization(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def body(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The body of the customization
        """
        return pulumi.get(self, "body")

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> pulumi.Output[_builtins.str]:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @_builtins.property
    @pulumi.getter(name="forceIsDefault")
    @_utilities.deprecated("""force_is_default is deprecated and now is a no-op in behavior. Rely upon the depends_on meta argument to force dependency of secondary templates to the default template""")
    def force_is_default(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Force is_default on the create and delete by deleting all email customizations. Comma separated string with values of 'create' or 'destroy' or both `create,destroy'.
        """
        return pulumi.get(self, "force_is_default")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the customization is the default
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter
    def language(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The language supported by the customization - Example values from [supported languages](https://developer.okta.com/docs/reference/api/brands/#supported-languages)
        """
        return pulumi.get(self, "language")

    @_builtins.property
    @pulumi.getter
    def links(self) -> pulumi.Output[_builtins.str]:
        """
        Link relations for this object - JSON HAL - Discoverable resources related to the email template
        """
        return pulumi.get(self, "links")

    @_builtins.property
    @pulumi.getter
    def subject(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The subject of the customization
        """
        return pulumi.get(self, "subject")

    @_builtins.property
    @pulumi.getter(name="templateName")
    def template_name(self) -> pulumi.Output[_builtins.str]:
        """
        Template Name - Example values: `AccountLockout`,`ADForgotPassword`,`ADForgotPasswordDenied`,`ADSelfServiceUnlock`,`ADUserActivation`,`AuthenticatorEnrolled`,`AuthenticatorReset`,`ChangeEmailConfirmation`,`EmailChallenge`,`EmailChangeConfirmation`,`EmailFactorVerification`,`ForgotPassword`,`ForgotPasswordDenied`,`IGAReviewerEndNotification`,`IGAReviewerNotification`,`IGAReviewerPendingNotification`,`IGAReviewerReassigned`,`LDAPForgotPassword`,`LDAPForgotPasswordDenied`,`LDAPSelfServiceUnlock`,`LDAPUserActivation`,`MyAccountChangeConfirmation`,`NewSignOnNotification`,`OktaVerifyActivation`,`PasswordChanged`,`PasswordResetByAdmin`,`PendingEmailChange`,`RegistrationActivation`,`RegistrationEmailVerification`,`SelfServiceUnlock`,`SelfServiceUnlockOnUnlockedAccount`,`UserActivation`
        """
        return pulumi.get(self, "template_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AuthenticatorArgs', 'Authenticator']

@pulumi.input_type
class AuthenticatorArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[_builtins.str],
                 agree_to_terms: Optional[pulumi.Input[_builtins.bool]] = None,
                 legacy_ignore_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_auth_port: Optional[pulumi.Input[_builtins.int]] = None,
                 provider_host: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_integration_key: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_json: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_shared_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_user_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Authenticator resource.
        :param pulumi.Input[_builtins.str] key: A human-readable string that identifies the authenticator. Some authenticators are available by feature flag on the organization. Possible values inclue: `custom_app`, `custom_otp`, `duo`, `external_idp`, `google_otp`, `okta_email`, `okta_password`, `okta_verify`, `onprem_mfa`, `phone_number`, `rsa_token`, `security_question`, `webauthn`
        :param pulumi.Input[_builtins.bool] agree_to_terms: A value of true indicates that the administrator accepts the terms for creating a new authenticator. Okta requires that you accept the terms when creating a new custom_app authenticator. Other authenticators don't require this field.
        :param pulumi.Input[_builtins.bool] legacy_ignore_name: Name does not trigger change detection (legacy behavior). Must be set to false for custom_app authenticators.
        :param pulumi.Input[_builtins.str] name: Display name of the Authenticator
        :param pulumi.Input[_builtins.int] provider_auth_port: The RADIUS server port (for example 1812). This is defined when the On-Prem RADIUS server is configured. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_host: (DUO specific) - The Duo Security API hostname. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_hostname: Server host name or IP address. Default is `localhost`. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_integration_key: (DUO specific) - The Duo Security integration key.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_json: Provider JSON allows for expressive providervalues. This argument conflicts with the other 'provider_xxx' arguments. The [CreateProvider](https://developer.okta.com/docs/reference/api/authenticators-admin/#request) illustrates detailed provider values for a Duo authenticator. [Provider values](https://developer.okta.com/docs/reference/api/authenticators-admin/#authenticators-administration-api-object)are listed in Okta API.
        :param pulumi.Input[_builtins.str] provider_secret_key: (DUO specific) - The Duo Security secret key.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_shared_secret: An authentication key that must be defined when the RADIUS server is configured, and must be the same on both the RADIUS client and server. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_user_name_template: Username template expected by the provider. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] settings: Settings for the authenticator. The settings JSON contains values based on Authenticator key. It is not used for authenticators with type `security_key`
        :param pulumi.Input[_builtins.str] status: Authenticator status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        """
        pulumi.set(__self__, "key", key)
        if agree_to_terms is not None:
            pulumi.set(__self__, "agree_to_terms", agree_to_terms)
        if legacy_ignore_name is not None:
            pulumi.set(__self__, "legacy_ignore_name", legacy_ignore_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_auth_port is not None:
            pulumi.set(__self__, "provider_auth_port", provider_auth_port)
        if provider_host is not None:
            pulumi.set(__self__, "provider_host", provider_host)
        if provider_hostname is not None:
            pulumi.set(__self__, "provider_hostname", provider_hostname)
        if provider_integration_key is not None:
            pulumi.set(__self__, "provider_integration_key", provider_integration_key)
        if provider_json is not None:
            pulumi.set(__self__, "provider_json", provider_json)
        if provider_secret_key is not None:
            pulumi.set(__self__, "provider_secret_key", provider_secret_key)
        if provider_shared_secret is not None:
            pulumi.set(__self__, "provider_shared_secret", provider_shared_secret)
        if provider_user_name_template is not None:
            pulumi.set(__self__, "provider_user_name_template", provider_user_name_template)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Input[_builtins.str]:
        """
        A human-readable string that identifies the authenticator. Some authenticators are available by feature flag on the organization. Possible values inclue: `custom_app`, `custom_otp`, `duo`, `external_idp`, `google_otp`, `okta_email`, `okta_password`, `okta_verify`, `onprem_mfa`, `phone_number`, `rsa_token`, `security_question`, `webauthn`
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter(name="agreeToTerms")
    def agree_to_terms(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        A value of true indicates that the administrator accepts the terms for creating a new authenticator. Okta requires that you accept the terms when creating a new custom_app authenticator. Other authenticators don't require this field.
        """
        return pulumi.get(self, "agree_to_terms")

    @agree_to_terms.setter
    def agree_to_terms(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "agree_to_terms", value)

    @_builtins.property
    @pulumi.getter(name="legacyIgnoreName")
    def legacy_ignore_name(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Name does not trigger change detection (legacy behavior). Must be set to false for custom_app authenticators.
        """
        return pulumi.get(self, "legacy_ignore_name")

    @legacy_ignore_name.setter
    def legacy_ignore_name(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "legacy_ignore_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Display name of the Authenticator
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerAuthPort")
    def provider_auth_port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The RADIUS server port (for example 1812). This is defined when the On-Prem RADIUS server is configured. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_auth_port")

    @provider_auth_port.setter
    def provider_auth_port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "provider_auth_port", value)

    @_builtins.property
    @pulumi.getter(name="providerHost")
    def provider_host(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (DUO specific) - The Duo Security API hostname. Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_host")

    @provider_host.setter
    def provider_host(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_host", value)

    @_builtins.property
    @pulumi.getter(name="providerHostname")
    def provider_hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Server host name or IP address. Default is `localhost`. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_hostname")

    @provider_hostname.setter
    def provider_hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_hostname", value)

    @_builtins.property
    @pulumi.getter(name="providerIntegrationKey")
    def provider_integration_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (DUO specific) - The Duo Security integration key.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_integration_key")

    @provider_integration_key.setter
    def provider_integration_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_integration_key", value)

    @_builtins.property
    @pulumi.getter(name="providerJson")
    def provider_json(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provider JSON allows for expressive providervalues. This argument conflicts with the other 'provider_xxx' arguments. The [CreateProvider](https://developer.okta.com/docs/reference/api/authenticators-admin/#request) illustrates detailed provider values for a Duo authenticator. [Provider values](https://developer.okta.com/docs/reference/api/authenticators-admin/#authenticators-administration-api-object)are listed in Okta API.
        """
        return pulumi.get(self, "provider_json")

    @provider_json.setter
    def provider_json(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_json", value)

    @_builtins.property
    @pulumi.getter(name="providerSecretKey")
    def provider_secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (DUO specific) - The Duo Security secret key.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_secret_key")

    @provider_secret_key.setter
    def provider_secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_secret_key", value)

    @_builtins.property
    @pulumi.getter(name="providerSharedSecret")
    def provider_shared_secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        An authentication key that must be defined when the RADIUS server is configured, and must be the same on both the RADIUS client and server. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_shared_secret")

    @provider_shared_secret.setter
    def provider_shared_secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_shared_secret", value)

    @_builtins.property
    @pulumi.getter(name="providerUserNameTemplate")
    def provider_user_name_template(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username template expected by the provider. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_user_name_template")

    @provider_user_name_template.setter
    def provider_user_name_template(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_user_name_template", value)

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Settings for the authenticator. The settings JSON contains values based on Authenticator key. It is not used for authenticators with type `security_key`
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "settings", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authenticator status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _AuthenticatorState:
    def __init__(__self__, *,
                 agree_to_terms: Optional[pulumi.Input[_builtins.bool]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 legacy_ignore_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_auth_port: Optional[pulumi.Input[_builtins.int]] = None,
                 provider_host: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_instance_id: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_integration_key: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_json: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_shared_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_user_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Authenticator resources.
        :param pulumi.Input[_builtins.bool] agree_to_terms: A value of true indicates that the administrator accepts the terms for creating a new authenticator. Okta requires that you accept the terms when creating a new custom_app authenticator. Other authenticators don't require this field.
        :param pulumi.Input[_builtins.str] key: A human-readable string that identifies the authenticator. Some authenticators are available by feature flag on the organization. Possible values inclue: `custom_app`, `custom_otp`, `duo`, `external_idp`, `google_otp`, `okta_email`, `okta_password`, `okta_verify`, `onprem_mfa`, `phone_number`, `rsa_token`, `security_question`, `webauthn`
        :param pulumi.Input[_builtins.bool] legacy_ignore_name: Name does not trigger change detection (legacy behavior). Must be set to false for custom_app authenticators.
        :param pulumi.Input[_builtins.str] name: Display name of the Authenticator
        :param pulumi.Input[_builtins.int] provider_auth_port: The RADIUS server port (for example 1812). This is defined when the On-Prem RADIUS server is configured. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_host: (DUO specific) - The Duo Security API hostname. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_hostname: Server host name or IP address. Default is `localhost`. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_instance_id: App Instance ID.
        :param pulumi.Input[_builtins.str] provider_integration_key: (DUO specific) - The Duo Security integration key.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_json: Provider JSON allows for expressive providervalues. This argument conflicts with the other 'provider_xxx' arguments. The [CreateProvider](https://developer.okta.com/docs/reference/api/authenticators-admin/#request) illustrates detailed provider values for a Duo authenticator. [Provider values](https://developer.okta.com/docs/reference/api/authenticators-admin/#authenticators-administration-api-object)are listed in Okta API.
        :param pulumi.Input[_builtins.str] provider_secret_key: (DUO specific) - The Duo Security secret key.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_shared_secret: An authentication key that must be defined when the RADIUS server is configured, and must be the same on both the RADIUS client and server. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_type: Provider type. Supported value for Duo: `DUO`. Supported value for Custom App: `PUSH`
        :param pulumi.Input[_builtins.str] provider_user_name_template: Username template expected by the provider. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] settings: Settings for the authenticator. The settings JSON contains values based on Authenticator key. It is not used for authenticators with type `security_key`
        :param pulumi.Input[_builtins.str] status: Authenticator status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        :param pulumi.Input[_builtins.str] type: he type of Authenticator. Values include: `password`, `security_question`, `phone`, `email`, `app`, `federated`, and `security_key`.
        """
        if agree_to_terms is not None:
            pulumi.set(__self__, "agree_to_terms", agree_to_terms)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if legacy_ignore_name is not None:
            pulumi.set(__self__, "legacy_ignore_name", legacy_ignore_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_auth_port is not None:
            pulumi.set(__self__, "provider_auth_port", provider_auth_port)
        if provider_host is not None:
            pulumi.set(__self__, "provider_host", provider_host)
        if provider_hostname is not None:
            pulumi.set(__self__, "provider_hostname", provider_hostname)
        if provider_instance_id is not None:
            pulumi.set(__self__, "provider_instance_id", provider_instance_id)
        if provider_integration_key is not None:
            pulumi.set(__self__, "provider_integration_key", provider_integration_key)
        if provider_json is not None:
            pulumi.set(__self__, "provider_json", provider_json)
        if provider_secret_key is not None:
            pulumi.set(__self__, "provider_secret_key", provider_secret_key)
        if provider_shared_secret is not None:
            pulumi.set(__self__, "provider_shared_secret", provider_shared_secret)
        if provider_type is not None:
            pulumi.set(__self__, "provider_type", provider_type)
        if provider_user_name_template is not None:
            pulumi.set(__self__, "provider_user_name_template", provider_user_name_template)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="agreeToTerms")
    def agree_to_terms(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        A value of true indicates that the administrator accepts the terms for creating a new authenticator. Okta requires that you accept the terms when creating a new custom_app authenticator. Other authenticators don't require this field.
        """
        return pulumi.get(self, "agree_to_terms")

    @agree_to_terms.setter
    def agree_to_terms(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "agree_to_terms", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A human-readable string that identifies the authenticator. Some authenticators are available by feature flag on the organization. Possible values inclue: `custom_app`, `custom_otp`, `duo`, `external_idp`, `google_otp`, `okta_email`, `okta_password`, `okta_verify`, `onprem_mfa`, `phone_number`, `rsa_token`, `security_question`, `webauthn`
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter(name="legacyIgnoreName")
    def legacy_ignore_name(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Name does not trigger change detection (legacy behavior). Must be set to false for custom_app authenticators.
        """
        return pulumi.get(self, "legacy_ignore_name")

    @legacy_ignore_name.setter
    def legacy_ignore_name(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "legacy_ignore_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Display name of the Authenticator
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerAuthPort")
    def provider_auth_port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The RADIUS server port (for example 1812). This is defined when the On-Prem RADIUS server is configured. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_auth_port")

    @provider_auth_port.setter
    def provider_auth_port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "provider_auth_port", value)

    @_builtins.property
    @pulumi.getter(name="providerHost")
    def provider_host(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (DUO specific) - The Duo Security API hostname. Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_host")

    @provider_host.setter
    def provider_host(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_host", value)

    @_builtins.property
    @pulumi.getter(name="providerHostname")
    def provider_hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Server host name or IP address. Default is `localhost`. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_hostname")

    @provider_hostname.setter
    def provider_hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_hostname", value)

    @_builtins.property
    @pulumi.getter(name="providerInstanceId")
    def provider_instance_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        App Instance ID.
        """
        return pulumi.get(self, "provider_instance_id")

    @provider_instance_id.setter
    def provider_instance_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_instance_id", value)

    @_builtins.property
    @pulumi.getter(name="providerIntegrationKey")
    def provider_integration_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (DUO specific) - The Duo Security integration key.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_integration_key")

    @provider_integration_key.setter
    def provider_integration_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_integration_key", value)

    @_builtins.property
    @pulumi.getter(name="providerJson")
    def provider_json(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provider JSON allows for expressive providervalues. This argument conflicts with the other 'provider_xxx' arguments. The [CreateProvider](https://developer.okta.com/docs/reference/api/authenticators-admin/#request) illustrates detailed provider values for a Duo authenticator. [Provider values](https://developer.okta.com/docs/reference/api/authenticators-admin/#authenticators-administration-api-object)are listed in Okta API.
        """
        return pulumi.get(self, "provider_json")

    @provider_json.setter
    def provider_json(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_json", value)

    @_builtins.property
    @pulumi.getter(name="providerSecretKey")
    def provider_secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (DUO specific) - The Duo Security secret key.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_secret_key")

    @provider_secret_key.setter
    def provider_secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_secret_key", value)

    @_builtins.property
    @pulumi.getter(name="providerSharedSecret")
    def provider_shared_secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        An authentication key that must be defined when the RADIUS server is configured, and must be the same on both the RADIUS client and server. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_shared_secret")

    @provider_shared_secret.setter
    def provider_shared_secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_shared_secret", value)

    @_builtins.property
    @pulumi.getter(name="providerType")
    def provider_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provider type. Supported value for Duo: `DUO`. Supported value for Custom App: `PUSH`
        """
        return pulumi.get(self, "provider_type")

    @provider_type.setter
    def provider_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_type", value)

    @_builtins.property
    @pulumi.getter(name="providerUserNameTemplate")
    def provider_user_name_template(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username template expected by the provider. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_user_name_template")

    @provider_user_name_template.setter
    def provider_user_name_template(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_user_name_template", value)

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Settings for the authenticator. The settings JSON contains values based on Authenticator key. It is not used for authenticators with type `security_key`
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "settings", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authenticator status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        he type of Authenticator. Values include: `password`, `security_question`, `phone`, `email`, `app`, `federated`, and `security_key`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("okta:index/authenticator:Authenticator")
class Authenticator(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agree_to_terms: Optional[pulumi.Input[_builtins.bool]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 legacy_ignore_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_auth_port: Optional[pulumi.Input[_builtins.int]] = None,
                 provider_host: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_integration_key: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_json: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_shared_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_user_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        > **WARNING:** This feature is only available as a part of the Identity Engine. Contact support for further information.

        This resource allows you to configure different authenticators.

        > **Create:** The Okta API has an odd notion of create for authenticators. If
        the authenticator doesn't exist then a one time 'POST /api/v1/authenticators' to
        create the authenticator (hard create) will be performed. Thereafter, that
        authenticator is never deleted, it is only deactivated (soft delete). Therefore,
        if the authenticator already exists create is just a soft import of an existing
        authenticator. This does not apply to custom_otp and custom_app authenticators.
        There can be multiple custom_otp authenticators. To create new custom_otp
        authenticator, a new name and key = custom_otp is required. If an old name is
        used, it will simply reactivate the old custom_otp authenticator. For custom_app
        authenticators, legacy_ignore_name must be set to false.

        > **Update:** custom_otp authenticator cannot be updated

        > **Delete:** Authenticators can not be truly deleted therefore delete is soft.
        Delete will attempt to deativate the authenticator. An authenticator can only be
        deactivated if it's not in use by any other policy.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_okta as okta

        test = okta.Authenticator("test",
            name="Security Question",
            key="security_question",
            settings=json.dumps({
                "allowedFor": "recovery",
            }))
        otp = okta.Authenticator("otp",
            name="Custom OTP",
            key="custom_otp",
            status="ACTIVE",
            settings=json.dumps({
                "protocol": "TOTP",
                "acceptableAdjacentIntervals": 3,
                "timeIntervalInSeconds": 30,
                "encoding": "base32",
                "algorithm": "HMacSHA256",
                "passCodeLength": 6,
            }),
            legacy_ignore_name=False)
        custom_app = okta.Authenticator("custom_app",
            key="custom_app",
            name="Custom Push Auth",
            status="ACTIVE",
            agree_to_terms=True,
            legacy_ignore_name=False,
            settings=json.dumps({
                "userVerification": "REQUIRED",
                "appInstanceId": "0oasontedmcepr0Uf1d7",
            }),
            provider_json=json.dumps({
                "type": "PUSH",
                "configuration": {
                    "fcm": {
                        "id": "ppcrb12345678ABCDEF",
                    },
                },
            }))
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/authenticator:Authenticator example <authenticator_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] agree_to_terms: A value of true indicates that the administrator accepts the terms for creating a new authenticator. Okta requires that you accept the terms when creating a new custom_app authenticator. Other authenticators don't require this field.
        :param pulumi.Input[_builtins.str] key: A human-readable string that identifies the authenticator. Some authenticators are available by feature flag on the organization. Possible values inclue: `custom_app`, `custom_otp`, `duo`, `external_idp`, `google_otp`, `okta_email`, `okta_password`, `okta_verify`, `onprem_mfa`, `phone_number`, `rsa_token`, `security_question`, `webauthn`
        :param pulumi.Input[_builtins.bool] legacy_ignore_name: Name does not trigger change detection (legacy behavior). Must be set to false for custom_app authenticators.
        :param pulumi.Input[_builtins.str] name: Display name of the Authenticator
        :param pulumi.Input[_builtins.int] provider_auth_port: The RADIUS server port (for example 1812). This is defined when the On-Prem RADIUS server is configured. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_host: (DUO specific) - The Duo Security API hostname. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_hostname: Server host name or IP address. Default is `localhost`. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_integration_key: (DUO specific) - The Duo Security integration key.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_json: Provider JSON allows for expressive providervalues. This argument conflicts with the other 'provider_xxx' arguments. The [CreateProvider](https://developer.okta.com/docs/reference/api/authenticators-admin/#request) illustrates detailed provider values for a Duo authenticator. [Provider values](https://developer.okta.com/docs/reference/api/authenticators-admin/#authenticators-administration-api-object)are listed in Okta API.
        :param pulumi.Input[_builtins.str] provider_secret_key: (DUO specific) - The Duo Security secret key.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_shared_secret: An authentication key that must be defined when the RADIUS server is configured, and must be the same on both the RADIUS client and server. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_user_name_template: Username template expected by the provider. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] settings: Settings for the authenticator. The settings JSON contains values based on Authenticator key. It is not used for authenticators with type `security_key`
        :param pulumi.Input[_builtins.str] status: Authenticator status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AuthenticatorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        > **WARNING:** This feature is only available as a part of the Identity Engine. Contact support for further information.

        This resource allows you to configure different authenticators.

        > **Create:** The Okta API has an odd notion of create for authenticators. If
        the authenticator doesn't exist then a one time 'POST /api/v1/authenticators' to
        create the authenticator (hard create) will be performed. Thereafter, that
        authenticator is never deleted, it is only deactivated (soft delete). Therefore,
        if the authenticator already exists create is just a soft import of an existing
        authenticator. This does not apply to custom_otp and custom_app authenticators.
        There can be multiple custom_otp authenticators. To create new custom_otp
        authenticator, a new name and key = custom_otp is required. If an old name is
        used, it will simply reactivate the old custom_otp authenticator. For custom_app
        authenticators, legacy_ignore_name must be set to false.

        > **Update:** custom_otp authenticator cannot be updated

        > **Delete:** Authenticators can not be truly deleted therefore delete is soft.
        Delete will attempt to deativate the authenticator. An authenticator can only be
        deactivated if it's not in use by any other policy.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_okta as okta

        test = okta.Authenticator("test",
            name="Security Question",
            key="security_question",
            settings=json.dumps({
                "allowedFor": "recovery",
            }))
        otp = okta.Authenticator("otp",
            name="Custom OTP",
            key="custom_otp",
            status="ACTIVE",
            settings=json.dumps({
                "protocol": "TOTP",
                "acceptableAdjacentIntervals": 3,
                "timeIntervalInSeconds": 30,
                "encoding": "base32",
                "algorithm": "HMacSHA256",
                "passCodeLength": 6,
            }),
            legacy_ignore_name=False)
        custom_app = okta.Authenticator("custom_app",
            key="custom_app",
            name="Custom Push Auth",
            status="ACTIVE",
            agree_to_terms=True,
            legacy_ignore_name=False,
            settings=json.dumps({
                "userVerification": "REQUIRED",
                "appInstanceId": "0oasontedmcepr0Uf1d7",
            }),
            provider_json=json.dumps({
                "type": "PUSH",
                "configuration": {
                    "fcm": {
                        "id": "ppcrb12345678ABCDEF",
                    },
                },
            }))
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/authenticator:Authenticator example <authenticator_id>
        ```

        :param str resource_name: The name of the resource.
        :param AuthenticatorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuthenticatorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agree_to_terms: Optional[pulumi.Input[_builtins.bool]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 legacy_ignore_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_auth_port: Optional[pulumi.Input[_builtins.int]] = None,
                 provider_host: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_integration_key: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_json: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_shared_secret: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_user_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuthenticatorArgs.__new__(AuthenticatorArgs)

            __props__.__dict__["agree_to_terms"] = agree_to_terms
            if key is None and not opts.urn:
                raise TypeError("Missing required property 'key'")
            __props__.__dict__["key"] = key
            __props__.__dict__["legacy_ignore_name"] = legacy_ignore_name
            __props__.__dict__["name"] = name
            __props__.__dict__["provider_auth_port"] = provider_auth_port
            __props__.__dict__["provider_host"] = provider_host
            __props__.__dict__["provider_hostname"] = provider_hostname
            __props__.__dict__["provider_integration_key"] = provider_integration_key
            __props__.__dict__["provider_json"] = provider_json
            __props__.__dict__["provider_secret_key"] = provider_secret_key
            __props__.__dict__["provider_shared_secret"] = None if provider_shared_secret is None else pulumi.Output.secret(provider_shared_secret)
            __props__.__dict__["provider_user_name_template"] = provider_user_name_template
            __props__.__dict__["settings"] = settings
            __props__.__dict__["status"] = status
            __props__.__dict__["provider_instance_id"] = None
            __props__.__dict__["provider_type"] = None
            __props__.__dict__["type"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["providerSharedSecret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Authenticator, __self__).__init__(
            'okta:index/authenticator:Authenticator',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            agree_to_terms: Optional[pulumi.Input[_builtins.bool]] = None,
            key: Optional[pulumi.Input[_builtins.str]] = None,
            legacy_ignore_name: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            provider_auth_port: Optional[pulumi.Input[_builtins.int]] = None,
            provider_host: Optional[pulumi.Input[_builtins.str]] = None,
            provider_hostname: Optional[pulumi.Input[_builtins.str]] = None,
            provider_instance_id: Optional[pulumi.Input[_builtins.str]] = None,
            provider_integration_key: Optional[pulumi.Input[_builtins.str]] = None,
            provider_json: Optional[pulumi.Input[_builtins.str]] = None,
            provider_secret_key: Optional[pulumi.Input[_builtins.str]] = None,
            provider_shared_secret: Optional[pulumi.Input[_builtins.str]] = None,
            provider_type: Optional[pulumi.Input[_builtins.str]] = None,
            provider_user_name_template: Optional[pulumi.Input[_builtins.str]] = None,
            settings: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'Authenticator':
        """
        Get an existing Authenticator resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] agree_to_terms: A value of true indicates that the administrator accepts the terms for creating a new authenticator. Okta requires that you accept the terms when creating a new custom_app authenticator. Other authenticators don't require this field.
        :param pulumi.Input[_builtins.str] key: A human-readable string that identifies the authenticator. Some authenticators are available by feature flag on the organization. Possible values inclue: `custom_app`, `custom_otp`, `duo`, `external_idp`, `google_otp`, `okta_email`, `okta_password`, `okta_verify`, `onprem_mfa`, `phone_number`, `rsa_token`, `security_question`, `webauthn`
        :param pulumi.Input[_builtins.bool] legacy_ignore_name: Name does not trigger change detection (legacy behavior). Must be set to false for custom_app authenticators.
        :param pulumi.Input[_builtins.str] name: Display name of the Authenticator
        :param pulumi.Input[_builtins.int] provider_auth_port: The RADIUS server port (for example 1812). This is defined when the On-Prem RADIUS server is configured. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_host: (DUO specific) - The Duo Security API hostname. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_hostname: Server host name or IP address. Default is `localhost`. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_instance_id: App Instance ID.
        :param pulumi.Input[_builtins.str] provider_integration_key: (DUO specific) - The Duo Security integration key.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_json: Provider JSON allows for expressive providervalues. This argument conflicts with the other 'provider_xxx' arguments. The [CreateProvider](https://developer.okta.com/docs/reference/api/authenticators-admin/#request) illustrates detailed provider values for a Duo authenticator. [Provider values](https://developer.okta.com/docs/reference/api/authenticators-admin/#authenticators-administration-api-object)are listed in Okta API.
        :param pulumi.Input[_builtins.str] provider_secret_key: (DUO specific) - The Duo Security secret key.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_shared_secret: An authentication key that must be defined when the RADIUS server is configured, and must be the same on both the RADIUS client and server. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] provider_type: Provider type. Supported value for Duo: `DUO`. Supported value for Custom App: `PUSH`
        :param pulumi.Input[_builtins.str] provider_user_name_template: Username template expected by the provider. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        :param pulumi.Input[_builtins.str] settings: Settings for the authenticator. The settings JSON contains values based on Authenticator key. It is not used for authenticators with type `security_key`
        :param pulumi.Input[_builtins.str] status: Authenticator status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        :param pulumi.Input[_builtins.str] type: he type of Authenticator. Values include: `password`, `security_question`, `phone`, `email`, `app`, `federated`, and `security_key`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuthenticatorState.__new__(_AuthenticatorState)

        __props__.__dict__["agree_to_terms"] = agree_to_terms
        __props__.__dict__["key"] = key
        __props__.__dict__["legacy_ignore_name"] = legacy_ignore_name
        __props__.__dict__["name"] = name
        __props__.__dict__["provider_auth_port"] = provider_auth_port
        __props__.__dict__["provider_host"] = provider_host
        __props__.__dict__["provider_hostname"] = provider_hostname
        __props__.__dict__["provider_instance_id"] = provider_instance_id
        __props__.__dict__["provider_integration_key"] = provider_integration_key
        __props__.__dict__["provider_json"] = provider_json
        __props__.__dict__["provider_secret_key"] = provider_secret_key
        __props__.__dict__["provider_shared_secret"] = provider_shared_secret
        __props__.__dict__["provider_type"] = provider_type
        __props__.__dict__["provider_user_name_template"] = provider_user_name_template
        __props__.__dict__["settings"] = settings
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return Authenticator(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="agreeToTerms")
    def agree_to_terms(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        A value of true indicates that the administrator accepts the terms for creating a new authenticator. Okta requires that you accept the terms when creating a new custom_app authenticator. Other authenticators don't require this field.
        """
        return pulumi.get(self, "agree_to_terms")

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Output[_builtins.str]:
        """
        A human-readable string that identifies the authenticator. Some authenticators are available by feature flag on the organization. Possible values inclue: `custom_app`, `custom_otp`, `duo`, `external_idp`, `google_otp`, `okta_email`, `okta_password`, `okta_verify`, `onprem_mfa`, `phone_number`, `rsa_token`, `security_question`, `webauthn`
        """
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter(name="legacyIgnoreName")
    def legacy_ignore_name(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Name does not trigger change detection (legacy behavior). Must be set to false for custom_app authenticators.
        """
        return pulumi.get(self, "legacy_ignore_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Display name of the Authenticator
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerAuthPort")
    def provider_auth_port(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The RADIUS server port (for example 1812). This is defined when the On-Prem RADIUS server is configured. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_auth_port")

    @_builtins.property
    @pulumi.getter(name="providerHost")
    def provider_host(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        (DUO specific) - The Duo Security API hostname. Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_host")

    @_builtins.property
    @pulumi.getter(name="providerHostname")
    def provider_hostname(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Server host name or IP address. Default is `localhost`. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_hostname")

    @_builtins.property
    @pulumi.getter(name="providerInstanceId")
    def provider_instance_id(self) -> pulumi.Output[_builtins.str]:
        """
        App Instance ID.
        """
        return pulumi.get(self, "provider_instance_id")

    @_builtins.property
    @pulumi.getter(name="providerIntegrationKey")
    def provider_integration_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        (DUO specific) - The Duo Security integration key.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_integration_key")

    @_builtins.property
    @pulumi.getter(name="providerJson")
    def provider_json(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Provider JSON allows for expressive providervalues. This argument conflicts with the other 'provider_xxx' arguments. The [CreateProvider](https://developer.okta.com/docs/reference/api/authenticators-admin/#request) illustrates detailed provider values for a Duo authenticator. [Provider values](https://developer.okta.com/docs/reference/api/authenticators-admin/#authenticators-administration-api-object)are listed in Okta API.
        """
        return pulumi.get(self, "provider_json")

    @_builtins.property
    @pulumi.getter(name="providerSecretKey")
    def provider_secret_key(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        (DUO specific) - The Duo Security secret key.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_secret_key")

    @_builtins.property
    @pulumi.getter(name="providerSharedSecret")
    def provider_shared_secret(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        An authentication key that must be defined when the RADIUS server is configured, and must be the same on both the RADIUS client and server. Used only for authenticators with type `security_key`. Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_shared_secret")

    @_builtins.property
    @pulumi.getter(name="providerType")
    def provider_type(self) -> pulumi.Output[_builtins.str]:
        """
        Provider type. Supported value for Duo: `DUO`. Supported value for Custom App: `PUSH`
        """
        return pulumi.get(self, "provider_type")

    @_builtins.property
    @pulumi.getter(name="providerUserNameTemplate")
    def provider_user_name_template(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Username template expected by the provider. Used only for authenticators with type `security_key`.  Conflicts with `provider_json` argument.
        """
        return pulumi.get(self, "provider_user_name_template")

    @_builtins.property
    @pulumi.getter
    def settings(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Settings for the authenticator. The settings JSON contains values based on Authenticator key. It is not used for authenticators with type `security_key`
        """
        return pulumi.get(self, "settings")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Authenticator status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        he type of Authenticator. Values include: `password`, `security_question`, `phone`, `email`, `app`, `federated`, and `security_key`.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RequestSequenceArgs', 'RequestSequence']

@pulumi.input_type
class RequestSequenceArgs:
    def __init__(__self__, *,
                 id_property: pulumi.Input[_builtins.str],
                 resource_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a RequestSequence resource.
        :param pulumi.Input[_builtins.str] id_property: The id of the sequence.Must be of 24 characters length.
        :param pulumi.Input[_builtins.str] resource_id: The id of the resource in Okta ID format.
        """
        pulumi.set(__self__, "id_property", id_property)
        pulumi.set(__self__, "resource_id", resource_id)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the sequence.Must be of 24 characters length.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the resource in Okta ID format.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_id", value)


@pulumi.input_type
class _RequestSequenceState:
    def __init__(__self__, *,
                 compatible_resource_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 link: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RequestSequence resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] compatible_resource_types: Enum: `APP`, `GROUP`.
        :param pulumi.Input[_builtins.str] description: The description of the request condition.
        :param pulumi.Input[_builtins.str] id_property: The id of the sequence.Must be of 24 characters length.
        :param pulumi.Input[_builtins.str] link: Link to edit the request sequence.
        :param pulumi.Input[_builtins.str] name: The access duration settings for the request condition
        :param pulumi.Input[_builtins.str] resource_id: The id of the resource in Okta ID format.
        """
        if compatible_resource_types is not None:
            pulumi.set(__self__, "compatible_resource_types", compatible_resource_types)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if id_property is not None:
            pulumi.set(__self__, "id_property", id_property)
        if link is not None:
            pulumi.set(__self__, "link", link)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)

    @_builtins.property
    @pulumi.getter(name="compatibleResourceTypes")
    def compatible_resource_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Enum: `APP`, `GROUP`.
        """
        return pulumi.get(self, "compatible_resource_types")

    @compatible_resource_types.setter
    def compatible_resource_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "compatible_resource_types", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the request condition.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the sequence.Must be of 24 characters length.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter
    def link(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Link to edit the request sequence.
        """
        return pulumi.get(self, "link")

    @link.setter
    def link(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "link", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access duration settings for the request condition
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the resource in Okta ID format.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_id", value)


@pulumi.type_token("okta:index/requestSequence:RequestSequence")
class RequestSequence(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages request sequence. This resource allows you to read and delete an Okta [request-sequence](https://developer.okta.com/docs/api/iga/openapi/governance.requests.admin.v2/tag/Request-Sequences/#tag/Request-Sequences).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.RequestSequence("test",
            id_property="<sequence_id>",
            resource_id="<resource_id>")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/requestSequence:RequestSequence example <resource_id>/<id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] id_property: The id of the sequence.Must be of 24 characters length.
        :param pulumi.Input[_builtins.str] resource_id: The id of the resource in Okta ID format.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RequestSequenceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages request sequence. This resource allows you to read and delete an Okta [request-sequence](https://developer.okta.com/docs/api/iga/openapi/governance.requests.admin.v2/tag/Request-Sequences/#tag/Request-Sequences).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.RequestSequence("test",
            id_property="<sequence_id>",
            resource_id="<resource_id>")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/requestSequence:RequestSequence example <resource_id>/<id>
        ```

        :param str resource_name: The name of the resource.
        :param RequestSequenceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RequestSequenceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RequestSequenceArgs.__new__(RequestSequenceArgs)

            if id_property is None and not opts.urn:
                raise TypeError("Missing required property 'id_property'")
            __props__.__dict__["id_property"] = id_property
            if resource_id is None and not opts.urn:
                raise TypeError("Missing required property 'resource_id'")
            __props__.__dict__["resource_id"] = resource_id
            __props__.__dict__["compatible_resource_types"] = None
            __props__.__dict__["description"] = None
            __props__.__dict__["link"] = None
            __props__.__dict__["name"] = None
        super(RequestSequence, __self__).__init__(
            'okta:index/requestSequence:RequestSequence',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compatible_resource_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            id_property: Optional[pulumi.Input[_builtins.str]] = None,
            link: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            resource_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'RequestSequence':
        """
        Get an existing RequestSequence resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] compatible_resource_types: Enum: `APP`, `GROUP`.
        :param pulumi.Input[_builtins.str] description: The description of the request condition.
        :param pulumi.Input[_builtins.str] id_property: The id of the sequence.Must be of 24 characters length.
        :param pulumi.Input[_builtins.str] link: Link to edit the request sequence.
        :param pulumi.Input[_builtins.str] name: The access duration settings for the request condition
        :param pulumi.Input[_builtins.str] resource_id: The id of the resource in Okta ID format.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RequestSequenceState.__new__(_RequestSequenceState)

        __props__.__dict__["compatible_resource_types"] = compatible_resource_types
        __props__.__dict__["description"] = description
        __props__.__dict__["id_property"] = id_property
        __props__.__dict__["link"] = link
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_id"] = resource_id
        return RequestSequence(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="compatibleResourceTypes")
    def compatible_resource_types(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Enum: `APP`, `GROUP`.
        """
        return pulumi.get(self, "compatible_resource_types")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        The description of the request condition.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the sequence.Must be of 24 characters length.
        """
        return pulumi.get(self, "id_property")

    @_builtins.property
    @pulumi.getter
    def link(self) -> pulumi.Output[_builtins.str]:
        """
        Link to edit the request sequence.
        """
        return pulumi.get(self, "link")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The access duration settings for the request condition
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the resource in Okta ID format.
        """
        return pulumi.get(self, "resource_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetThemesResult',
    'AwaitableGetThemesResult',
    'get_themes',
    'get_themes_output',
]

@pulumi.output_type
class GetThemesResult:
    """
    A collection of values returned by getThemes.
    """
    def __init__(__self__, brand_id=None, id=None, themes=None):
        if brand_id and not isinstance(brand_id, str):
            raise TypeError("Expected argument 'brand_id' to be a str")
        pulumi.set(__self__, "brand_id", brand_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if themes and not isinstance(themes, list):
            raise TypeError("Expected argument 'themes' to be a list")
        pulumi.set(__self__, "themes", themes)

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> _builtins.str:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def themes(self) -> Sequence['outputs.GetThemesThemeResult']:
        """
        List of `okta_them` belonging to the brand in the organization
        """
        return pulumi.get(self, "themes")


class AwaitableGetThemesResult(GetThemesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetThemesResult(
            brand_id=self.brand_id,
            id=self.id,
            themes=self.themes)


def get_themes(brand_id: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetThemesResult:
    """
    Get Themes of a Brand of an Okta Organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_brands()
    example = okta.get_themes(brand_id=test.brands[0].id)
    ```


    :param _builtins.str brand_id: Brand ID
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getThemes:getThemes', __args__, opts=opts, typ=GetThemesResult).value

    return AwaitableGetThemesResult(
        brand_id=pulumi.get(__ret__, 'brand_id'),
        id=pulumi.get(__ret__, 'id'),
        themes=pulumi.get(__ret__, 'themes'))
def get_themes_output(brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetThemesResult]:
    """
    Get Themes of a Brand of an Okta Organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_brands()
    example = okta.get_themes(brand_id=test.brands[0].id)
    ```


    :param _builtins.str brand_id: Brand ID
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getThemes:getThemes', __args__, opts=opts, typ=GetThemesResult)
    return __ret__.apply(lambda __response__: GetThemesResult(
        brand_id=pulumi.get(__response__, 'brand_id'),
        id=pulumi.get(__response__, 'id'),
        themes=pulumi.get(__response__, 'themes')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AgentPoolUpdateArgs', 'AgentPoolUpdate']

@pulumi.input_type
class AgentPoolUpdateArgs:
    def __init__(__self__, *,
                 pool_id: pulumi.Input[_builtins.str],
                 agent_type: Optional[pulumi.Input[_builtins.str]] = None,
                 agents: Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_admins: Optional[pulumi.Input[_builtins.bool]] = None,
                 notify_on_completion: Optional[pulumi.Input[_builtins.bool]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']] = None,
                 sort_order: Optional[pulumi.Input[_builtins.int]] = None,
                 target_version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AgentPoolUpdate resource.
        :param pulumi.Input[_builtins.str] pool_id: The unique identifier of the agent pool to update.
        :param pulumi.Input[_builtins.str] agent_type: Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        :param pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]] agents: The agents associated with the agent pool update.
        :param pulumi.Input[_builtins.str] description: The description of the agent pool update.
        :param pulumi.Input[_builtins.bool] enabled: Whether auto-update is enabled for the agent pool.
        :param pulumi.Input[_builtins.str] name: The name of the agent pool update.
        :param pulumi.Input[_builtins.bool] notify_admins: Whether to notify admins about the update.
        :param pulumi.Input[_builtins.bool] notify_on_completion: Whether to send notifications when the update completes.
        :param pulumi.Input[_builtins.str] reason: Reason for the update.
        :param pulumi.Input['AgentPoolUpdateScheduleArgs'] schedule: The schedule configuration for the agent pool update.
        :param pulumi.Input[_builtins.int] sort_order: Specifies the sort order.
        :param pulumi.Input[_builtins.str] target_version: The agent version to update to.
        """
        pulumi.set(__self__, "pool_id", pool_id)
        if agent_type is not None:
            pulumi.set(__self__, "agent_type", agent_type)
        if agents is not None:
            pulumi.set(__self__, "agents", agents)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notify_admins is not None:
            pulumi.set(__self__, "notify_admins", notify_admins)
        if notify_on_completion is not None:
            pulumi.set(__self__, "notify_on_completion", notify_on_completion)
        if reason is not None:
            pulumi.set(__self__, "reason", reason)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if sort_order is not None:
            pulumi.set(__self__, "sort_order", sort_order)
        if target_version is not None:
            pulumi.set(__self__, "target_version", target_version)

    @_builtins.property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> pulumi.Input[_builtins.str]:
        """
        The unique identifier of the agent pool to update.
        """
        return pulumi.get(self, "pool_id")

    @pool_id.setter
    def pool_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pool_id", value)

    @_builtins.property
    @pulumi.getter(name="agentType")
    def agent_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        """
        return pulumi.get(self, "agent_type")

    @agent_type.setter
    def agent_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "agent_type", value)

    @_builtins.property
    @pulumi.getter
    def agents(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]]:
        """
        The agents associated with the agent pool update.
        """
        return pulumi.get(self, "agents")

    @agents.setter
    def agents(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]]):
        pulumi.set(self, "agents", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the agent pool update.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether auto-update is enabled for the agent pool.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the agent pool update.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notifyAdmins")
    def notify_admins(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to notify admins about the update.
        """
        return pulumi.get(self, "notify_admins")

    @notify_admins.setter
    def notify_admins(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "notify_admins", value)

    @_builtins.property
    @pulumi.getter(name="notifyOnCompletion")
    def notify_on_completion(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to send notifications when the update completes.
        """
        return pulumi.get(self, "notify_on_completion")

    @notify_on_completion.setter
    def notify_on_completion(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "notify_on_completion", value)

    @_builtins.property
    @pulumi.getter
    def reason(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Reason for the update.
        """
        return pulumi.get(self, "reason")

    @reason.setter
    def reason(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reason", value)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']]:
        """
        The schedule configuration for the agent pool update.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @_builtins.property
    @pulumi.getter(name="sortOrder")
    def sort_order(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the sort order.
        """
        return pulumi.get(self, "sort_order")

    @sort_order.setter
    def sort_order(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "sort_order", value)

    @_builtins.property
    @pulumi.getter(name="targetVersion")
    def target_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The agent version to update to.
        """
        return pulumi.get(self, "target_version")

    @target_version.setter
    def target_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_version", value)


@pulumi.input_type
class _AgentPoolUpdateState:
    def __init__(__self__, *,
                 agent_type: Optional[pulumi.Input[_builtins.str]] = None,
                 agents: Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_admins: Optional[pulumi.Input[_builtins.bool]] = None,
                 notify_on_completion: Optional[pulumi.Input[_builtins.bool]] = None,
                 pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']] = None,
                 sort_order: Optional[pulumi.Input[_builtins.int]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 target_version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AgentPoolUpdate resources.
        :param pulumi.Input[_builtins.str] agent_type: Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        :param pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]] agents: The agents associated with the agent pool update.
        :param pulumi.Input[_builtins.str] description: The description of the agent pool update.
        :param pulumi.Input[_builtins.bool] enabled: Whether auto-update is enabled for the agent pool.
        :param pulumi.Input[_builtins.str] name: The name of the agent pool update.
        :param pulumi.Input[_builtins.bool] notify_admins: Whether to notify admins about the update.
        :param pulumi.Input[_builtins.bool] notify_on_completion: Whether to send notifications when the update completes.
        :param pulumi.Input[_builtins.str] pool_id: The unique identifier of the agent pool to update.
        :param pulumi.Input[_builtins.str] reason: Reason for the update.
        :param pulumi.Input['AgentPoolUpdateScheduleArgs'] schedule: The schedule configuration for the agent pool update.
        :param pulumi.Input[_builtins.int] sort_order: Specifies the sort order.
        :param pulumi.Input[_builtins.str] status: The status of the agent pool update (e.g., Scheduled, InProgress, Completed, Failed).
        :param pulumi.Input[_builtins.str] target_version: The agent version to update to.
        """
        if agent_type is not None:
            pulumi.set(__self__, "agent_type", agent_type)
        if agents is not None:
            pulumi.set(__self__, "agents", agents)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notify_admins is not None:
            pulumi.set(__self__, "notify_admins", notify_admins)
        if notify_on_completion is not None:
            pulumi.set(__self__, "notify_on_completion", notify_on_completion)
        if pool_id is not None:
            pulumi.set(__self__, "pool_id", pool_id)
        if reason is not None:
            pulumi.set(__self__, "reason", reason)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if sort_order is not None:
            pulumi.set(__self__, "sort_order", sort_order)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if target_version is not None:
            pulumi.set(__self__, "target_version", target_version)

    @_builtins.property
    @pulumi.getter(name="agentType")
    def agent_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        """
        return pulumi.get(self, "agent_type")

    @agent_type.setter
    def agent_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "agent_type", value)

    @_builtins.property
    @pulumi.getter
    def agents(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]]:
        """
        The agents associated with the agent pool update.
        """
        return pulumi.get(self, "agents")

    @agents.setter
    def agents(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]]):
        pulumi.set(self, "agents", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the agent pool update.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether auto-update is enabled for the agent pool.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the agent pool update.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notifyAdmins")
    def notify_admins(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to notify admins about the update.
        """
        return pulumi.get(self, "notify_admins")

    @notify_admins.setter
    def notify_admins(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "notify_admins", value)

    @_builtins.property
    @pulumi.getter(name="notifyOnCompletion")
    def notify_on_completion(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to send notifications when the update completes.
        """
        return pulumi.get(self, "notify_on_completion")

    @notify_on_completion.setter
    def notify_on_completion(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "notify_on_completion", value)

    @_builtins.property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the agent pool to update.
        """
        return pulumi.get(self, "pool_id")

    @pool_id.setter
    def pool_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pool_id", value)

    @_builtins.property
    @pulumi.getter
    def reason(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Reason for the update.
        """
        return pulumi.get(self, "reason")

    @reason.setter
    def reason(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reason", value)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']]:
        """
        The schedule configuration for the agent pool update.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @_builtins.property
    @pulumi.getter(name="sortOrder")
    def sort_order(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the sort order.
        """
        return pulumi.get(self, "sort_order")

    @sort_order.setter
    def sort_order(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "sort_order", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the agent pool update (e.g., Scheduled, InProgress, Completed, Failed).
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="targetVersion")
    def target_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The agent version to update to.
        """
        return pulumi.get(self, "target_version")

    @target_version.setter
    def target_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_version", value)


@pulumi.type_token("okta:index/agentPoolUpdate:AgentPoolUpdate")
class AgentPoolUpdate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_type: Optional[pulumi.Input[_builtins.str]] = None,
                 agents: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AgentPoolUpdateAgentArgs', 'AgentPoolUpdateAgentArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_admins: Optional[pulumi.Input[_builtins.bool]] = None,
                 notify_on_completion: Optional[pulumi.Input[_builtins.bool]] = None,
                 pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['AgentPoolUpdateScheduleArgs', 'AgentPoolUpdateScheduleArgsDict']]] = None,
                 sort_order: Optional[pulumi.Input[_builtins.int]] = None,
                 target_version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages an Okta Agent Pool Update. Agent pool updates allow you to schedule and manage updates for agent pools.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.AgentPoolUpdate("example",
            name="scheduled_update",
            agent_type="AD",
            notify_admins=True,
            pool_id="0oaspf3cfatE1nDO31d7",
            agents=[{
                "id": "a53slzqkptH2xEJ1r1d7",
                "pool_id": "0oaspf3cfatE1nDO31d7",
            }],
            schedule={
                "cron": "0 3 * * MON",
                "timezone": "America/Los_Angeles",
                "delay": 0,
                "duration": 1020,
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/agentPoolUpdate:AgentPoolUpdate example <pool_id>/<update_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] agent_type: Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        :param pulumi.Input[Sequence[pulumi.Input[Union['AgentPoolUpdateAgentArgs', 'AgentPoolUpdateAgentArgsDict']]]] agents: The agents associated with the agent pool update.
        :param pulumi.Input[_builtins.str] description: The description of the agent pool update.
        :param pulumi.Input[_builtins.bool] enabled: Whether auto-update is enabled for the agent pool.
        :param pulumi.Input[_builtins.str] name: The name of the agent pool update.
        :param pulumi.Input[_builtins.bool] notify_admins: Whether to notify admins about the update.
        :param pulumi.Input[_builtins.bool] notify_on_completion: Whether to send notifications when the update completes.
        :param pulumi.Input[_builtins.str] pool_id: The unique identifier of the agent pool to update.
        :param pulumi.Input[_builtins.str] reason: Reason for the update.
        :param pulumi.Input[Union['AgentPoolUpdateScheduleArgs', 'AgentPoolUpdateScheduleArgsDict']] schedule: The schedule configuration for the agent pool update.
        :param pulumi.Input[_builtins.int] sort_order: Specifies the sort order.
        :param pulumi.Input[_builtins.str] target_version: The agent version to update to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AgentPoolUpdateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an Okta Agent Pool Update. Agent pool updates allow you to schedule and manage updates for agent pools.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.AgentPoolUpdate("example",
            name="scheduled_update",
            agent_type="AD",
            notify_admins=True,
            pool_id="0oaspf3cfatE1nDO31d7",
            agents=[{
                "id": "a53slzqkptH2xEJ1r1d7",
                "pool_id": "0oaspf3cfatE1nDO31d7",
            }],
            schedule={
                "cron": "0 3 * * MON",
                "timezone": "America/Los_Angeles",
                "delay": 0,
                "duration": 1020,
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/agentPoolUpdate:AgentPoolUpdate example <pool_id>/<update_id>
        ```

        :param str resource_name: The name of the resource.
        :param AgentPoolUpdateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AgentPoolUpdateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_type: Optional[pulumi.Input[_builtins.str]] = None,
                 agents: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AgentPoolUpdateAgentArgs', 'AgentPoolUpdateAgentArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_admins: Optional[pulumi.Input[_builtins.bool]] = None,
                 notify_on_completion: Optional[pulumi.Input[_builtins.bool]] = None,
                 pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['AgentPoolUpdateScheduleArgs', 'AgentPoolUpdateScheduleArgsDict']]] = None,
                 sort_order: Optional[pulumi.Input[_builtins.int]] = None,
                 target_version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AgentPoolUpdateArgs.__new__(AgentPoolUpdateArgs)

            __props__.__dict__["agent_type"] = agent_type
            __props__.__dict__["agents"] = agents
            __props__.__dict__["description"] = description
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["notify_admins"] = notify_admins
            __props__.__dict__["notify_on_completion"] = notify_on_completion
            if pool_id is None and not opts.urn:
                raise TypeError("Missing required property 'pool_id'")
            __props__.__dict__["pool_id"] = pool_id
            __props__.__dict__["reason"] = reason
            __props__.__dict__["schedule"] = schedule
            __props__.__dict__["sort_order"] = sort_order
            __props__.__dict__["target_version"] = target_version
            __props__.__dict__["status"] = None
        super(AgentPoolUpdate, __self__).__init__(
            'okta:index/agentPoolUpdate:AgentPoolUpdate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            agent_type: Optional[pulumi.Input[_builtins.str]] = None,
            agents: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AgentPoolUpdateAgentArgs', 'AgentPoolUpdateAgentArgsDict']]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            notify_admins: Optional[pulumi.Input[_builtins.bool]] = None,
            notify_on_completion: Optional[pulumi.Input[_builtins.bool]] = None,
            pool_id: Optional[pulumi.Input[_builtins.str]] = None,
            reason: Optional[pulumi.Input[_builtins.str]] = None,
            schedule: Optional[pulumi.Input[Union['AgentPoolUpdateScheduleArgs', 'AgentPoolUpdateScheduleArgsDict']]] = None,
            sort_order: Optional[pulumi.Input[_builtins.int]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            target_version: Optional[pulumi.Input[_builtins.str]] = None) -> 'AgentPoolUpdate':
        """
        Get an existing AgentPoolUpdate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] agent_type: Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        :param pulumi.Input[Sequence[pulumi.Input[Union['AgentPoolUpdateAgentArgs', 'AgentPoolUpdateAgentArgsDict']]]] agents: The agents associated with the agent pool update.
        :param pulumi.Input[_builtins.str] description: The description of the agent pool update.
        :param pulumi.Input[_builtins.bool] enabled: Whether auto-update is enabled for the agent pool.
        :param pulumi.Input[_builtins.str] name: The name of the agent pool update.
        :param pulumi.Input[_builtins.bool] notify_admins: Whether to notify admins about the update.
        :param pulumi.Input[_builtins.bool] notify_on_completion: Whether to send notifications when the update completes.
        :param pulumi.Input[_builtins.str] pool_id: The unique identifier of the agent pool to update.
        :param pulumi.Input[_builtins.str] reason: Reason for the update.
        :param pulumi.Input[Union['AgentPoolUpdateScheduleArgs', 'AgentPoolUpdateScheduleArgsDict']] schedule: The schedule configuration for the agent pool update.
        :param pulumi.Input[_builtins.int] sort_order: Specifies the sort order.
        :param pulumi.Input[_builtins.str] status: The status of the agent pool update (e.g., Scheduled, InProgress, Completed, Failed).
        :param pulumi.Input[_builtins.str] target_version: The agent version to update to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AgentPoolUpdateState.__new__(_AgentPoolUpdateState)

        __props__.__dict__["agent_type"] = agent_type
        __props__.__dict__["agents"] = agents
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["notify_admins"] = notify_admins
        __props__.__dict__["notify_on_completion"] = notify_on_completion
        __props__.__dict__["pool_id"] = pool_id
        __props__.__dict__["reason"] = reason
        __props__.__dict__["schedule"] = schedule
        __props__.__dict__["sort_order"] = sort_order
        __props__.__dict__["status"] = status
        __props__.__dict__["target_version"] = target_version
        return AgentPoolUpdate(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="agentType")
    def agent_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        """
        return pulumi.get(self, "agent_type")

    @_builtins.property
    @pulumi.getter
    def agents(self) -> pulumi.Output[Optional[Sequence['outputs.AgentPoolUpdateAgent']]]:
        """
        The agents associated with the agent pool update.
        """
        return pulumi.get(self, "agents")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the agent pool update.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether auto-update is enabled for the agent pool.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the agent pool update.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notifyAdmins")
    def notify_admins(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to notify admins about the update.
        """
        return pulumi.get(self, "notify_admins")

    @_builtins.property
    @pulumi.getter(name="notifyOnCompletion")
    def notify_on_completion(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to send notifications when the update completes.
        """
        return pulumi.get(self, "notify_on_completion")

    @_builtins.property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the agent pool to update.
        """
        return pulumi.get(self, "pool_id")

    @_builtins.property
    @pulumi.getter
    def reason(self) -> pulumi.Output[_builtins.str]:
        """
        Reason for the update.
        """
        return pulumi.get(self, "reason")

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> pulumi.Output[Optional['outputs.AgentPoolUpdateSchedule']]:
        """
        The schedule configuration for the agent pool update.
        """
        return pulumi.get(self, "schedule")

    @_builtins.property
    @pulumi.getter(name="sortOrder")
    def sort_order(self) -> pulumi.Output[_builtins.int]:
        """
        Specifies the sort order.
        """
        return pulumi.get(self, "sort_order")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the agent pool update (e.g., Scheduled, InProgress, Completed, Failed).
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="targetVersion")
    def target_version(self) -> pulumi.Output[_builtins.str]:
        """
        The agent version to update to.
        """
        return pulumi.get(self, "target_version")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetGroupsResult',
    'AwaitableGetGroupsResult',
    'get_groups',
    'get_groups_output',
]

@pulumi.output_type
class GetGroupsResult:
    """
    A collection of values returned by getGroups.
    """
    def __init__(__self__, groups=None, id=None, limit=None, q=None, search=None, type=None):
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if limit and not isinstance(limit, int):
            raise TypeError("Expected argument 'limit' to be a int")
        pulumi.set(__self__, "limit", limit)
        if q and not isinstance(q, str):
            raise TypeError("Expected argument 'q' to be a str")
        pulumi.set(__self__, "q", q)
        if search and not isinstance(search, str):
            raise TypeError("Expected argument 'search' to be a str")
        pulumi.set(__self__, "search", search)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def groups(self) -> Sequence['outputs.GetGroupsGroupResult']:
        return pulumi.get(self, "groups")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def limit(self) -> Optional[_builtins.int]:
        """
        The maximum number of groups returned by the Okta API, between 1 and 10000.
        """
        return pulumi.get(self, "limit")

    @_builtins.property
    @pulumi.getter
    def q(self) -> Optional[_builtins.str]:
        """
        Searches the name property of groups for matching value
        """
        return pulumi.get(self, "q")

    @_builtins.property
    @pulumi.getter
    def search(self) -> Optional[_builtins.str]:
        """
        Searches for groups with a supported filtering expression for all attributes except for '*embedded', '*links', and 'objectClass'
        """
        return pulumi.get(self, "search")

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "type")


class AwaitableGetGroupsResult(GetGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupsResult(
            groups=self.groups,
            id=self.id,
            limit=self.limit,
            q=self.q,
            search=self.search,
            type=self.type)


def get_groups(limit: Optional[_builtins.int] = None,
               q: Optional[_builtins.str] = None,
               search: Optional[_builtins.str] = None,
               type: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupsResult:
    """
    Get a list of groups from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_groups(q="Engineering - ")
    ```


    :param _builtins.int limit: The maximum number of groups returned by the Okta API, between 1 and 10000.
    :param _builtins.str q: Searches the name property of groups for matching value
    :param _builtins.str search: Searches for groups with a supported filtering expression for all attributes except for '*embedded', '*links', and 'objectClass'
    """
    __args__ = dict()
    __args__['limit'] = limit
    __args__['q'] = q
    __args__['search'] = search
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getGroups:getGroups', __args__, opts=opts, typ=GetGroupsResult).value

    return AwaitableGetGroupsResult(
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'),
        limit=pulumi.get(__ret__, 'limit'),
        q=pulumi.get(__ret__, 'q'),
        search=pulumi.get(__ret__, 'search'),
        type=pulumi.get(__ret__, 'type'))
def get_groups_output(limit: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                      q: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      search: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupsResult]:
    """
    Get a list of groups from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_groups(q="Engineering - ")
    ```


    :param _builtins.int limit: The maximum number of groups returned by the Okta API, between 1 and 10000.
    :param _builtins.str q: Searches the name property of groups for matching value
    :param _builtins.str search: Searches for groups with a supported filtering expression for all attributes except for '*embedded', '*links', and 'objectClass'
    """
    __args__ = dict()
    __args__['limit'] = limit
    __args__['q'] = q
    __args__['search'] = search
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getGroups:getGroups', __args__, opts=opts, typ=GetGroupsResult)
    return __ret__.apply(lambda __response__: GetGroupsResult(
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id'),
        limit=pulumi.get(__response__, 'limit'),
        q=pulumi.get(__response__, 'q'),
        search=pulumi.get(__response__, 'search'),
        type=pulumi.get(__response__, 'type')))
